<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Önyükleme Onarımı</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="45"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Önyükleme Onarımı, GRUB önyükleyicisini ESP’ye (EFI Sistem Bölümü), MBR’ye (Ana Önyükleme Kaydı) veya kök bölüme yeniden yüklemek için kullanılabilecek bir programdır. GRUB yapılandırma dosyasını yeniden oluşturma ve MBR’yi veya PBR’yi (kök) yedekleme ve geri yükleme seçeneği sunar.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="64"/>
        <source>What would you like to do?</source>
        <translation>Ne yapmak istersin?</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="94"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Yedek MBR veya PBR (yalnızca eski önyükleme)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="70"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>GRUB önyükleyiciyi ESP, MBR veya PBR’ye (root) yeniden kur</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="80"/>
        <source>Repair GRUB configuration file</source>
        <translation>GRUB yapılandırma dosyasını onar</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="87"/>
        <source>Regenerate initramfs images</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="101"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>MBR veya PBR’yi yedekten geri yükle (yalnızca eski önyükleme)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="134"/>
        <location filename="../src/gui/mainwindow.cpp" line="425"/>
        <source>Select Boot Method</source>
        <translation>Önyükleme Yöntemini Seçin</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="152"/>
        <source>Master Boot Record</source>
        <translation>Ana Önyükleme Kaydı</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="155"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="158"/>
        <location filename="../src/gui/mainwindow.ui" line="398"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="193"/>
        <location filename="../src/gui/mainwindow.cpp" line="426"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="218"/>
        <source>EFI System Partition</source>
        <translation>EFİ Sistem Bölümü</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="221"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="240"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Bölüm Önyükleme Kaydı)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="243"/>
        <location filename="../src/gui/mainwindow.cpp" line="428"/>
        <source>root</source>
        <translation>Kök</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="278"/>
        <location filename="../src/gui/mainwindow.cpp" line="433"/>
        <source>Select root location:</source>
        <translation>Kök bölümü seçin:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="300"/>
        <location filename="../src/gui/mainwindow.cpp" line="427"/>
        <source>Install on:</source>
        <translation>Buraya kur:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="389"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="392"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="440"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="443"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="449"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="490"/>
        <source>Cancel any changes then quit</source>
        <translation>Değişiklikleri iptal et ve çık</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="493"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="499"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="518"/>
        <source>Apply any changes</source>
        <translation>Değişiklikleri uygula</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="521"/>
        <location filename="../src/gui/mainwindow.cpp" line="82"/>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="461"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="102"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB %1 aygıtına kuruluyor.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="292"/>
        <location filename="../src/gui/mainwindow.cpp" line="350"/>
        <location filename="../src/gui/mainwindow.cpp" line="466"/>
        <location filename="../src/gui/mainwindow.cpp" line="470"/>
        <location filename="../src/gui/mainwindow.cpp" line="477"/>
        <location filename="../src/gui/mainwindow.cpp" line="483"/>
        <location filename="../src/gui/mainwindow.cpp" line="491"/>
        <location filename="../src/gui/mainwindow.cpp" line="498"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="142"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>GRUB yapılandırma dosyası (grub.cfg) yeniden oluşturuluyor.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="176"/>
        <source>Generating initramfs images on: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="205"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>%1 cihazından MBR veya PBR yedekleniyor.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="261"/>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="262"/>
        <source>You are going to write the content of </source>
        <translation>Şunun içeriğini yazacaksınız</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="262"/>
        <source> to </source>
        <translation>’e</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="263"/>
        <source>

Are you sure?</source>
        <translation>

Emin misiniz?</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="269"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>MBR/PBR yedekten %1 cihazına kuruluyor.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="293"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Hiçbir sistem diskinde EFI sistem bölümü (ESP) bulunamadı. Lütfen bir ESP oluşturun ve tekrar deneyin.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="305"/>
        <source>Select %1 location:</source>
        <translation>%1 konumunu seçin:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="328"/>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="344"/>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="344"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>İşlem başarıyla sona erdi. &lt;p&gt;&lt;b&gt;MX Önyükleme Onarımı’ndan çıkmak ister misiniz?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="350"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Süreç tamamlandı. Bir hata oluştu.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="109"/>
        <location filename="../src/gui/mainwindow.cpp" line="150"/>
        <location filename="../src/gui/mainwindow.cpp" line="182"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>%1 şifreli bölümün kilidini açmak için şifreyi girin:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="432"/>
        <source>Select GRUB location</source>
        <translation>GRUB konumunu seçin</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="441"/>
        <source>Select initramfs options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="451"/>
        <source>Select Item to Back Up</source>
        <translation>Yedeklenecek Öğeyi Seçin</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="456"/>
        <source>Select Item to Restore</source>
        <translation>Geri Yüklenecek Öğeyi Seçin</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="466"/>
        <location filename="../src/gui/mainwindow.cpp" line="477"/>
        <source>No location was selected.</source>
        <translation>Konum seçilmedi.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="471"/>
        <location filename="../src/gui/mainwindow.cpp" line="484"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Lütfen düzeltmek istediğiniz sistemin kök bölümünü seçin.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="489"/>
        <source>Select backup file name</source>
        <translation>Yedekleme dosyası adı seçimi</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="491"/>
        <location filename="../src/gui/mainwindow.cpp" line="498"/>
        <source>No file was selected.</source>
        <translation>Hiçbir dosya seçilmedi.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="496"/>
        <source>Select MBR or PBR backup file</source>
        <translation>MBR veya PBR yedek dosyasını seçin</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="514"/>
        <source>About %1</source>
        <translation>Hakkında %1</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="516"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="517"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>MX Linux için basit bir önyükleme onarma programı</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="519"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Telif Hakkı (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="520"/>
        <source>%1 License</source>
        <translation>%1 Telif Hakkı</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="533"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/gui/about.cpp" line="52"/>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="53"/>
        <location filename="../src/gui/about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="86"/>
        <source>MX Boot Repair</source>
        <translation>MX Önyükleme Onarımı</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="94"/>
        <source>MX Boot Repair - GUI and CLI tool for repairing GRUB bootloader</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="99"/>
        <source>Force CLI mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="100"/>
        <source>Print actions without executing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="101"/>
        <source>Do not prompt; require flags</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="102"/>
        <source>Action: install, repair, initramfs, backup, restore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="103"/>
        <source>Target for install: mbr, esp, root</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="104"/>
        <source>Device for target (e.g., sda, sda1)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="105"/>
        <source>Root partition (e.g., /dev/sda2)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="106"/>
        <source>Partition to mount at /boot in chroot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="107"/>
        <source>Partition to mount at /boot/efi in chroot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="108"/>
        <source>Path for backup/restore image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="109"/>
        <source>Skip confirmations (for restore)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="110"/>
        <source>Enable verbose output</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="111"/>
        <source>Suppress non-error output</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="121"/>
        <source>Error: --verbose and --quiet options are mutually exclusive
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="127"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="128"/>
        <source>You must run this program with admin access.</source>
        <translation>Bu programı yönetici erişimiyle çalıştırmalısınız.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="29"/>
        <source>Invalid index. Try again: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="48"/>
        <source>Invalid selection. Enter a number </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="234"/>
        <source>MX Boot Repair (CLI)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="235"/>
        <source>1) Install GRUB</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="236"/>
        <source>2) Repair GRUB (update-grub)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="237"/>
        <source>3) Regenerate initramfs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="238"/>
        <source>4) Backup MBR/PBR</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="239"/>
        <source>5) Restore MBR/PBR</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="240"/>
        <source>q) Quit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="241"/>
        <source>Select action [1-5 or &apos;q&apos; to quit]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="247"/>
        <source>Invalid selection. Enter 1-5 or &apos;q&apos; to quit.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="252"/>
        <source>Target: 0) MBR  1) ESP  2) Root</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="253"/>
        <source>Select target</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="259"/>
        <location filename="../src/cli/controller.cpp" line="297"/>
        <location filename="../src/cli/controller.cpp" line="310"/>
        <source>No partitions found. Returning to main menu.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="263"/>
        <location filename="../src/cli/controller.cpp" line="323"/>
        <location filename="../src/cli/controller.cpp" line="341"/>
        <source>No disks found. Returning to main menu.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="268"/>
        <source>Select disk for MBR (e.g., sda)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="272"/>
        <source>Select partition for GRUB (e.g., sda1)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="277"/>
        <source>Select root partition of installed system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="298"/>
        <source>Select root partition to repair</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="311"/>
        <source>Select root partition to regenerate initramfs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="324"/>
        <source>Select disk to back up MBR/PBR from</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="327"/>
        <source>Output file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="342"/>
        <source>Select disk to restore MBR/PBR to</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="345"/>
        <source>Input backup file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="352"/>
        <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="352"/>
        <source>. Continue? [y/N]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="355"/>
        <source>yes</source>
        <comment>confirmation input: full word</comment>
        <translation>evet</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="356"/>
        <source>y</source>
        <comment>confirmation input: single-letter yes</comment>
        <translation>y</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="360"/>
        <source>Cancelled.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="367"/>
        <source>Unknown selection</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>